@@ -100,6 +100,35 @@ test_that("parse_filestrings works correctly", {
     "test3")
 })
 
+test_that("read_gcfile reads xlsx files correctly", {
+  setwd(tempdir())
+  #Only run the Excel tests if xlsx loads successfully
+  run_xlsx <- tryCatch(
+    {library(xlsx)
+      TRUE},
+    error = function(e) {return(FALSE)},
+    warning = function(w) {return(TRUE)}
+  )
+  if(run_xlsx) {
+    testdf <- data.frame(matrix(LETTERS[1:25], nrow = 5, ncol = 5))
+    testdf[1, ] <- as.character(NA)
+    testdf[, 1] <- as.character(NA)
+    testdf[1:4, 5] <- as.character(NA)
+    testdf[5, 1:4] <- as.character(NA)
+    colnames(testdf) <- paste0("...", 1:5)
+    row.names(testdf) <- 1:5
+    xlsx::write.xlsx(testdf,
+                     file = "testdf.xlsx",
+                     sheetName = "Sheet1",
+                     showNA = FALSE, append = FALSE,
+                     col.names = FALSE, row.names = FALSE)
+    
+    expect_equal(read_gcfile(file = "testdf.xlsx", filetype = "xlsx",
+                             na.strings = c("NA", "")), 
+                 testdf)
+  }
+})
+
 
 test_that("read_blocks reads data correctly", {
   #Make test blockcurves data
@@ -163,6 +192,24 @@ test_that("read_blocks reads data correctly", {
     metadata = list("type1" = c(9, "I"), "type2" = c("E", 8)))
   expect_equal(my_blockcurves1_excelnumbers, my_blockcurves1_expected)
   
+  #Reading only one column of data
+  my_blockcurves1_narrow <- read_blocks(
+    files = paste("./test_blockcurves_data_csv/",
+                  list.files("./test_blockcurves_data_csv/"), sep = ""),
+    startrow = 1, startcol = 1, endrow = 9, endcol = 2)
+  
+  my_blockcurves1_narrow_expected <- rep(list(NA), length(example_dfs_list))
+  for (i in 1:length(my_blockcurves1_narrow_expected)) {
+    my_blockcurves1_narrow_expected[[i]] <- 
+      list(data = example_dfs_list[[i]][1:8, 1, drop = FALSE],
+           metadata = c(block_name = paste("test_blockcurves_data_csv/",
+                                           formatC(i, width = 3, flag = "0"),
+                                           sep = "")))
+    row.names(my_blockcurves1_narrow_expected[[i]]$data) <-
+      as.character(row.names(my_blockcurves1_narrow_expected[[i]]$data))
+  }
+  expect_equal(my_blockcurves1_narrow, my_blockcurves1_narrow_expected)
+  
   #Read xlsx with all rows/cols specified, metadata included
   if(run_xlsx) {
     my_blockcurves2 <- read_blocks(
@@ -191,6 +238,23 @@ test_that("read_blocks reads data correctly", {
       metadata = list("type1" = c("I", 9), "type2" = c(5, "H")))
     expect_equal(my_blockcurves2_excel, my_blockcurves2_expected)
     
+    #Reading only one column of data
+    my_blockcurves2_narrow <- read_blocks(
+      files = paste("./test_blockcurves_data_xlsx/",
+                    list.files("./test_blockcurves_data_xlsx/"), sep = ""),
+      startrow = 1, startcol = 1, endrow = 9, endcol = 2)
+    my_blockcurves2_narrow_expected <- rep(list(NA), length(example_dfs_list))
+    for (i in 1:length(my_blockcurves2_narrow_expected)) {
+      my_blockcurves2_narrow_expected[[i]] <- 
+        list(data = example_dfs_list[[i]][1:8, 1, drop = FALSE],
+             metadata = c(block_name = paste("test_blockcurves_data_xlsx/",
+                                             formatC(i, width = 3, flag = "0"),
+                                             sep = "")))
+      row.names(my_blockcurves2_narrow_expected[[i]]$data) <-
+        as.character(row.names(my_blockcurves2_narrow_expected[[i]]$data))
+    }
+    expect_equal(my_blockcurves2_narrow, my_blockcurves2_narrow_expected)
+    
     unlink("./test_blockcurves_data_xlsx", recursive = TRUE)
   }
   
@@ -297,6 +361,23 @@ test_that("read_wides works correctly", {
                       "test_widecurves_data/test" = data))
   }
   
+  #Only reading one column of data
+  if(!run_xlsx) {
+    data_in_narrow <- read_wides(
+      files = c("./test_widecurves_data/test.csv"),
+      endcol = 1, run_names_header = NULL)
+    expect_equal(data_in_narrow,
+                 data[, 1, drop = FALSE])
+  } else {
+    data_in_narrow <- read_wides(
+      files = c("./test_widecurves_data/test.csv",
+                "./test_widecurves_data/test.xlsx"),
+      endcol = 1, run_names_header = NULL)
+    expect_equal(data_in_narrow,
+                 list("test_widecurves_data/test" = data[, 1, drop = FALSE],
+                      "test_widecurves_data/test" = data[, 1, drop = FALSE]))
+  }
+  
   data2 <- cbind(data.frame(file = rep("test_widecurves_data/test", nrow(data))),
                  data)
   if(!run_xlsx) {
