@@ -44,6 +44,22 @@ test_that("Moving average returns correctly", {
                expected = c(NA, (25+49+64)/3, (49+64+81)/3,
                             NA, NA, NA, (1+4+9)/3,
                             (4+9+16)/3, (9+16+25)/3, (16+25+49)/3))
+  
+  #Now with all NA's
+  data4a <- data.frame(x = rep(NA, 10), y = 1:10)
+  expect_equal(moving_average(y ~ x, data = data4a, window_width_n = 3),
+               rep(as.numeric(NA), 10))
+  data4b <- data.frame(x = 1:10, y = rep(NA, 10))
+  expect_equal(moving_average(y ~ x, data = data4b, window_width_n = 3),
+               rep(as.numeric(NA), 10))
+  
+  #Now with nearly all NA's
+  data5a <- data.frame(x = c(5, rep(NA, 9)), y = 1:10)
+  expect_equal(moving_average(y ~ x, data = data5a, window_width_n = 3),
+               rep(as.numeric(NA), 10))
+  data5b <- data.frame(x = 1:10, y = c(5, rep(NA, 9)))
+  expect_equal(moving_average(y ~ x, data = data5b, window_width_n = 3),
+               rep(as.numeric(NA), 10))
 })
 
 test_that("Moving median returns correctly", {
@@ -82,6 +98,22 @@ test_that("Moving median returns correctly", {
                       y = c(NA, c(7:9)**2, 50, c(1:5)**2))
   expect_equal(moving_median(y ~ x, data3, window_width_n = 3),
                expected = c(NA, 49, 64, NA, NA, NA, 4, 9, 16, 25))
+  
+  #Now with all NA's
+  data4a <- data.frame(x = rep(NA, 10), y = 1:10)
+  expect_equal(moving_median(y ~ x, data = data4a, window_width_n = 3),
+               rep(as.numeric(NA), 10))
+  data4b <- data.frame(x = 1:10, y = rep(NA, 10))
+  expect_equal(moving_median(y ~ x, data = data4b, window_width_n = 3),
+               rep(as.numeric(NA), 10))
+  
+  #Now with nearly all NA's
+  data5a <- data.frame(x = c(5, rep(NA, 9)), y = 1:10)
+  expect_equal(moving_median(y ~ x, data = data5a, window_width_n = 3),
+               rep(as.numeric(NA), 10))
+  data5b <- data.frame(x = 1:10, y = c(5, rep(NA, 9)))
+  expect_equal(moving_median(y ~ x, data = data5b, window_width_n = 3),
+               rep(as.numeric(NA), 10))
 })
 
 test_that("smooth_data returns properly for moving-average", {
@@ -143,6 +175,32 @@ test_that("smooth_data returns properly for loess", {
                  sm = smooth_data(x = data3$x, y = data3$y,
                                   sm_method = "loess", span = 0.5))
   expect_equal(temp$sm, expected = expected3)
+  
+  #Now with all NA's
+  data4a <- data.frame(x = rep(NA, 10), y = 1:10)
+  data4a <- mutate(group_by(data4a, "A"),
+                   sm = smooth_data(x = x, y = y,
+                                    sm_method = "loess", span = 0.3))
+  expect_equal(data4a$sm, rep(as.numeric(NA), 10))
+
+  data4b <- data.frame(x = 1:10, y = rep(NA, 10))
+  data4b <- mutate(group_by(data4b, "A"),
+                   sm = smooth_data(x = x, y = y,
+                                    sm_method = "loess", span = 0.3))
+  expect_equal(data4b$sm, rep(as.numeric(NA), 10))
+  
+  #Now with nearly all NA's
+  data5a <- data.frame(x = c(5, rep(NA, 9)), y = 1:10)
+  data5a <- mutate(group_by(data5a, "A"),
+                   sm = smooth_data(x = x, y = y,
+                                    sm_method = "loess", span = 0.3))
+  expect_equal(data5a$sm, rep(as.numeric(NA), 10))
+  
+  data5b <- data.frame(x = 1:10, y = c(5, rep(NA, 9)))
+  data5b <- mutate(group_by(data5b, "A"),
+                   sm = smooth_data(x = x, y = y,
+                                    sm_method = "loess", span = 0.3))
+  expect_equal(data5b$sm, rep(as.numeric(NA), 10))
 })
 
 test_that("smooth_data returns properly for gam", {
@@ -216,6 +274,28 @@ test_that("smooth_data returns properly for gam", {
                  sm = smooth_data(x = time, y = dens, sm_method = "gam",
                                   k = 5, bs = "cr", subset = 1:90))
   expect_equal(temp$sm, expected = expect6)
+  
+  #Now with all NA's
+  data7a <- data.frame(x = rep(NA, 10), y = 1:10)
+  data7a <- mutate(group_by(data7a, "A"),
+                   sm = smooth_data(x = x, y = y, sm_method = "gam"))
+  expect_equal(data7a$sm, rep(as.numeric(NA), 10))
+  
+  data7b <- data.frame(x = 1:10, y = rep(NA, 10))
+  data7b <- mutate(group_by(data7b, "A"),
+                   sm = smooth_data(x = x, y = y, sm_method = "gam"))
+  expect_equal(data7b$sm, rep(as.numeric(NA), 10))
+  
+  #Now with nearly all NA's
+  data8a <- data.frame(x = c(5, rep(NA, 9)), y = 1:10)
+  data8a <- mutate(group_by(data8a, "A"),
+                   sm = smooth_data(x = x, y = y, sm_method = "gam"))
+  expect_equal(data8a$sm, rep(as.numeric(NA), 10))
+  
+  data8b <- data.frame(x = 1:10, y = c(5, rep(NA, 9)))
+  data8b <- mutate(group_by(data8b, "A"),
+                   sm = smooth_data(x = x, y = y, sm_method = "gam"))
+  expect_equal(data8b$sm, rep(as.numeric(NA), 10))
 })
 
 test_that("smooth_data returns properly for smooth.spline", {
@@ -282,11 +362,37 @@ test_that("smooth_data returns properly for smooth.spline", {
                                   sm_method = "smooth.spline", df = 7))
   expect_equal(temp$sm, expected = expect5)
   
-  expect5 <- stats::smooth.spline(x = data$x, y = data$y, spar = 0.5)$y
+  expect6 <- stats::smooth.spline(x = data$x, y = data$y, spar = 0.5)$y
   temp <- mutate(group_by(data, grp),
                  sm = smooth_data(x = x, y = y, 
                                   sm_method = "smooth.spline", spar = 0.5))
-  expect_equal(temp$sm, expected = expect5)
+  expect_equal(temp$sm, expected = expect6)
+  
+  #Now with all NA's
+  data7a <- data.frame(x = rep(NA, 10), y = 1:10)
+  data7a <- mutate(group_by(data7a, "A"),
+                   sm = smooth_data(x = x, y = y, 
+                                    sm_method = "smooth.spline", spar = 0.5))
+  expect_equal(data7a$sm, rep(as.numeric(NA), 10))
+  
+  data7b <- data.frame(x = 1:10, y = rep(NA, 10))
+  data7b <- mutate(group_by(data7b, "A"),
+                   sm = smooth_data(x = x, y = y, 
+                                    sm_method = "smooth.spline", spar = 0.5))
+  expect_equal(data7b$sm, rep(as.numeric(NA), 10))
+  
+  #Now with nearly all NA's
+  data8a <- data.frame(x = c(5, rep(NA, 9)), y = 1:10)
+  data8a <- mutate(group_by(data8a, "A"),
+                   sm = smooth_data(x = x, y = y, 
+                                    sm_method = "smooth.spline", spar = 0.5))
+  expect_equal(data8a$sm, rep(as.numeric(NA), 10))
+  
+  data8b <- data.frame(x = 1:10, y = c(5, rep(NA, 9)))
+  data8b <- mutate(group_by(data8b, "A"),
+                   sm = smooth_data(x = x, y = y, 
+                                    sm_method = "smooth.spline", spar = 0.5))
+  expect_equal(data8b$sm, rep(as.numeric(NA), 10))
 })
 
 
